# defining global variables and functions to appease R CMD Check

utils::globalVariables(
  names = c(
    ".",
    "U",
    "V",
    "Z",
    "chi",
    "counts",
    "df",
    "df1",
    "df2",
    "desc",
    "do",
    "effsize",
    "estimate",
    "eta",
    "omega",
    "perc",
    "cramer",
    "cramer_ci",
    "pvalue",
    "r",
    "rho",
    "xi",
    "y",
    "z_value",
    "italic",
    "rsubtitle",
    "stats_subtitle",
    "chi_subtitle",
    "proptest_subtitle",
    "LL",
    "UL",
    "outlier",
    "outlier.label",
    "proptest_subtitle",
    "significance",
    "..count..",
    "..density..",
    "dnorm",
    "mean",
    "median",
    "sd",
    "bf",
    "bf_error",
    "Df",
    "F value",
    "F.value",
    "LL",
    "Pr(>F)",
    "UL",
    "complete",
    "data",
    "df1",
    "df2",
    "effect",
    "effsize",
    "formula",
    "hist",
    "median",
    "p0",
    "p100",
    "p50",
    "p25",
    "p75",
    "sd",
    "type",
    "Chi-squared",
    "df",
    "p-value",
    "chi_sq",
    "significance",
    "F-value",
    "V2",
    "V3",
    "V4",
    "V5",
    "conf",
    "AIC",
    "BIC",
    "R",
    "adj.r.squared",
    "p.value",
    "term",
    "label",
    "loglik",
    "Pr(>|t|)",
    "coef",
    "conf.high",
    "conf.low",
    "rowid",
    "Cramer's V",
    "df[chiSq]",
    "p[chiSq]",
    "value[chiSq]",
    "condition_n_label",
    "total_n",
    "robust",
    "partial.etasq",
    "partial.omegasq",
    "stratum",
    "coefficient_type"
  ),
  package = "ggstatsplot",
  add = FALSE
)
